class WaterLevel(object):
    def __init__(self):
        self.device_id = ""
        self.name = "WATERLEVEL"
        self.measure = "-"
        self.absolute_measure = "-"
        self.setting_error = "0"
        self.setting_max = "100"
        self.setting_unit_measure = "cm"
        self.rules = []
        self.status = "disconnected"
        self.color = "red"
        self.unit_measure = "%"
        self.max_measure = "-"
        self.max_measure_time = "-"
        self.max_measure_date = "-"
        self.min_measure = "-"
        self.min_measure_time = "-"
        self.min_measure_date = "-"

    def device_mapping(self, device):
        self.device_id = device["device_id"]
        self.name = device["name"]
        self.setting_error = device["setting_error"]
        self.setting_max = device["setting_max"]
        self.setting_unit_measure = device["setting_unit_measure"]
        self.rules = device["rules"]



class Rule(object):
    def __init__(self):
        self.rule_id = ""
        self.rule_name = ""
        self.last_time_on = ""
        self.last_time_off = ""
        self.last_date_on = ""
        self.last_date_off = ""
        self.device_antecedents = []
        self.device_consequents = []
        self.antecedents = []
        self.consequents = []
        self.evaluation = "false"

    def json_mapping(self, rule_json):
        if "rule_name" in rule_json.keys():
            self.rule_name = rule_json["rule_name"]
        if "device_antecedents" in rule_json.keys():
            self.device_antecedents = rule_json["device_antecedents"]
        if "device_consequents" in rule_json.keys():
            self.device_consequents = rule_json["device_consequents"]
        if "antecedents" in rule_json.keys():
            self.antecedents = rule_json["antecedents"]
        if "consequents" in rule_json.keys():
            self.consequents = rule_json["consequents"]
